==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/javascript.karma/src/org/netbeans/modules/javascript/karma/preferences/KarmaPreferencesValidator.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */

package org.netbeans.modules.javascript.karma.preferences;

import org.netbeans.api.project.Project;
import org.netbeans.modules.javascript.karma.util.ExternalExecutableValidator;
import org.netbeans.modules.javascript.karma.util.FileUtils;
import org.netbeans.modules.javascript.karma.util.ValidationResult;
import org.openide.util.NbBundle;

public final class KarmaPreferencesValidator {

    private final ValidationResult result = new ValidationResult();


    public ValidationResult getResult() {
        return result;
    }

    public KarmaPreferencesValidator validate(Project project) {
        validateKarma(KarmaPreferences.getKarma(project));
        validateConfig(KarmaPreferences.getConfig(project));
        validateDebug(KarmaPreferences.isDebug(project), KarmaPreferences.getDebugBrowserId(project));
        return this;
    }

    @NbBundle.Messages("KarmaPreferencesValidator.karma.name=Karma")
    public KarmaPreferencesValidator validateKarma(String karma) {
        String warning = ExternalExecutableValidator.validateCommand(karma, Bundle.KarmaPreferencesValidator_karma_name());
        if (warning != null) {
            result.addWarning(new ValidationResult.Message("path", warning)); // NOI18N
        }
        return this;
    }

    @NbBundle.Messages("KarmaPreferencesValidator.config.name=Configuration")
    public KarmaPreferencesValidator validateConfig(String config) {
        String warning = FileUtils.validateFile(Bundle.KarmaPreferencesValidator_config_name(), config, false);
        if (warning != null) {
            result.addWarning(new ValidationResult.Message("config", warning)); // NOI18N
        }
        return this;
    }

    @NbBundle.Messages("KarmaPreferencesValidator.debug.browser=Browser for debugging must be set.")
    public KarmaPreferencesValidator validateDebug(boolean debug, String debugBrowserId) {
        if (debug
                && debugBrowserId == null) {
            result.addWarning(new ValidationResult.Message("debugBrowser", Bundle.KarmaPreferencesValidator_debug_browser())); // NOI18N
        }
        return this;
    }

}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/javascript.karma/src/org/netbeans/modules/javascript/karma/preferences/KarmaPreferencesValidator.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */

package org.netbeans.modules.javascript.karma.preferences;

import org.netbeans.api.project.Project;
import org.netbeans.modules.javascript.karma.util.FileUtils;
import org.netbeans.modules.web.common.api.ValidationResult;
import org.openide.util.NbBundle;

public final class KarmaPreferencesValidator {

    private final ValidationResult result = new ValidationResult();


    public ValidationResult getResult() {
        return result;
    }

    public KarmaPreferencesValidator validate(Project project) {
        validateConfig(KarmaPreferences.getConfig(project));
        validateDebug(KarmaPreferences.isDebug(project), KarmaPreferences.getDebugBrowserId(project));
        return this;
    }

    @NbBundle.Messages("KarmaPreferencesValidator.config.name=Configuration")
    public KarmaPreferencesValidator validateConfig(String config) {
        String warning = FileUtils.validateFile(Bundle.KarmaPreferencesValidator_config_name(), config, false);
        if (warning != null) {
            result.addWarning(new ValidationResult.Message("config", warning)); // NOI18N
        }
        return this;
    }

    @NbBundle.Messages("KarmaPreferencesValidator.debug.browser=Browser for debugging must be set.")
    public KarmaPreferencesValidator validateDebug(boolean debug, String debugBrowserId) {
        if (debug
                && debugBrowserId == null) {
            result.addWarning(new ValidationResult.Message("debugBrowser", Bundle.KarmaPreferencesValidator_debug_browser())); // NOI18N
        }
        return this;
    }

}
